## START: Set by rpmautospec
## (rpmautospec version 0.7.3)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

%global blender_api 4.4
%global macrosdir %(d=%{_rpmconfigdir}/macros.d; [ -d $d ] || d=%{_sysconfdir}/rpm; echo $d)
%global _without_bundled_deps 1

# Build conditionals
%bcond clang      0   # Use Clang compiler
%bcond draco      1   # Draco mesh compression support
%bcond llvm       1   # Required for OSL support
%bcond manpage    1   # Generate manpage
%bcond materialx  0   # MaterialX support
%bcond nanovdb    1   # NanoVDB support
%bcond ninja      1   # Use Ninja build system
%bcond openshading 1  # OpenShadingLanguage support
%bcond openvdb    1   # OpenVDB support
%bcond sdl        0   # SDL backend
%bcond system_eigen3 1 # Use system Eigen3
%bcond vulkan     1   # Vulkan rendering support

# Architecture-specific features
%ifarch x86_64 aarch64 ppc64le
%global cyclesflag ON
    # x86_64/aarch64 specific features
    %ifarch x86_64 aarch64
    %bcond embree 1   # Intel Embree ray tracing
    %bcond hidapi 1   # HIDAPI support
    
    # x86_64 exclusive features
    %ifarch x86_64
    %bcond hip   1    # AMD HIP support
    %bcond hiprt 1    # HIP ray tracing (requires Fedora 43+)
    %bcond oidn  1    # OpenImageDenoise
    %bcond oneapi 0   # Intel OneAPI support
    %bcond opgl  1    # OpenPGL
    %global llvm_compat 18
    %endif
    %bcond usd   1    # Universal Scene Description
%else
    %bcond embree 0
    %bcond hidapi 0
    %bcond oidn  0
    %bcond opgl  0
    %bcond usd   0
%endif
%else
%global cyclesflag OFF
%endif

Name:           blender
Epoch:          1
Version:        4.4.3
Release:        %autorelease

Summary:        3D modeling, animation, rendering and post-production
# Blender source is under GPL-2.0-or-later by default
# Apache-2.0 for Blender Cycles rendering engine
# BSD License for Open Shading Language
# Zlib License for Bullets
# GPL-3.0-or-later for the whole project
# https://www.blender.org/about/license/
License:	%{shrink:
		Apache-2.0 AND
  		BSD-3-Clause AND
  		GPL-2.0-or-later AND
  		GPL-3.0-or-later AND
  		Zlib
		}
URL:            https://www.blender.org

Source0:        https://download.%{name}.org/source/%{name}-%{version}.tar.xz
# Custom RPM macros
Source1:        %{name}-macros-source

# Build requirements
BuildRequires:  boost-devel
BuildRequires:  ccache
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  gcc-c++
BuildRequires:  gettext
BuildRequires:  git-core
BuildRequires:  libharu-devel
BuildRequires:  libtool
BuildRequires:  subversion-devel

# Conditional build deps
%if %{with clang}
BuildRequires:  clang%{?llvm_compat}-devel
%endif
%if %{with llvm}
BuildRequires:  llvm%{?llvm_compat}-devel
%endif
%if %{with ninja}
BuildRequires:  ninja-build
%endif

# System libraries
BuildRequires:  pkgconfig(blosc)
%if %{with system_eigen3}
BuildRequires:  pkgconfig(eigen3)
%endif
BuildRequires:  pkgconfig(epoxy) >= 1.5.10
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(gmp)
%if %{with hidapi}
BuildRequires:  pkgconfig(hidapi-hidraw)
%endif
BuildRequires:  pkgconfig(jemalloc)
BuildRequires:  pkgconfig(libpcre2-32)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(pugixml)
BuildRequires:  pkgconfig(python3) >= 3.7
%if %{with vulkan}
BuildRequires:  pkgconfig(shaderc)
BuildRequires:  pkgconfig(vulkan)
%endif
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:	pkgconfig(libdecor-0) >= 0.1.0
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xxf86vm)
BuildRequires:  subversion-devel

# Python stuff
BuildRequires:  python3dist(setuptools)
# In build_files/utils/make_bpy_wheel.py, the call to setuptools.setup has
# install_requires=["cython", "numpy", "requests", "zstandard"]; these are
# therefore both build-time and runtime dependencies.
BuildRequires:  python3dist(cython)
Requires:       python3dist(cython)
BuildRequires:  python3dist(numpy)
Requires:       python3dist(numpy)
BuildRequires:  python3dist(requests)
Requires:       python3dist(requests)
BuildRequires:  python3dist(zstandard)
Requires:       python3dist(zstandard)
# In source/creator/CMakeLists.txt, an attempt is made to add direct
# dependencies on certifi, (chardet or charset_normalizer), idna, and urllib3,
# as indirect dependencies that enable necessary functionality in requests. As
# packaged, requests already has a hard dependency on charset_normalizer, idna,
# and urllib3 – and it would depend on certifi, but this is correctly patched
# out in favor of explicitly and unconditional using the system certificate
# bundle. We therefore do not need to add direct dependencies on any of the
# above.
#
# Many Python scripts that are installed, especially from the add-ons, depend
# on various external Python packages. As far as we know, there is no clear
# listing of these that we can use as a reference to generate depdendencies
# automatically. A listing appears in PYTHON_SUBPACKAGES in
# build_files/build_environment/install_linux_packages.py, but the entries are
# redundant with those appearing above.
#
# Some dependencies can be found easily because they are required for testing;
# others may be less obvious. In general, each should be both a BuildRequires
# (even if not used in testing, to avoid accidentally building a Blender
# package that builds from source but fails to install due to an unsatisfied
# Requires) and a Requires (so users are not faced with “No module named '...'”
# errors).
#
# Something like this can help search for possible dependencies:
#
# rpm2cpio blender-4.1.1-1.fc40.x86_64.rpm | pax -r
# p='^[[:blank:]]*(from[[:blank:]]+[^[:blank:]]+[[:blank:]]+)?import\b'
# rg -I -g '*.py' "${p}" ./usr | awk '{print $2}' | grep -vE '^\.' | sort -u |
#   tee imports.txt
#
# This is an imperfect heuristic, but the result is generally a list of
# absolute imports that might reflect external dependencies. Some come from
# Blender; many come from the Python standard library. Those that remain are
# candidates for this list.
#
# The ant_landscape add-on has a weak dependency (used only if available) on
# numexpr; so does the mesh_tissue add-on.
BuildRequires:  python3dist(numexpr)
Recommends:     python3dist(numexpr)
# The ant_landscape add-on has a weak dependency on psutil.
BuildRequires:  python3dist(psutil)
Recommends:     python3dist(psutil)
#
# The mesh_tissue add-on has a weak dependency on numba. Numba is not packaged
# for Fedora, and probably never will be, because it is tied closely to the
# implementation details of a particular Python interpreter version, and can
# take six months to a year to support a new Python release.
# BuildRequires:  python3dist(numba)
# Recommends:     python3dist(numba)
# Only if numba is not available (see above), the mesh_tissue add-on falls back
# to using ensurepip to install pip, and then using pip to try to install numba
# from PyPI into the user site-packages. This *might* work. It is probably
# better if pip is already available.
BuildRequires:  python3dist(pip)
Recommends:     python3dist(pip)
#
# The io_mesh_uv_layout add-on has a weak dependency on OpenImageIO. Currently,
# the OpenImageIO package does not produce the necessary Python metadata for a
# dependency on python3dist(openimageio) to work.
BuildRequires:  python3-openimageio
Recommends:     python3-openimageio
#
# The io_export_dxf add-on requires pydevd (PyDev.Debugger,
# https://pypi.org/project/pydevd/) for debugging when the BLENDER_DEBUG
# environment variable is set. Since this is a debug-only dependency, we would
# choose not to add it even if it were packaged.
#
# The io_import_dxf add-on has a weak dependency on pyproj.
BuildRequires:  python3dist(pyproj)
Recommends:     python3dist(pyproj)
#
# %%{_datadir}/blender/%%{blender_api}/scripts/modules/bl_i18n_utils/utils_spell_check.py
# has "import enchant", but we judge that these scripts are really for people
# working on the translations, and should not be required in normal uses of the
# RPM package.

# Compression stuff
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(lzo2)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(libzstd)

# 3D modeling stuff
BuildRequires:  cmake(ceres)
%if %{with embree}
BuildRequires:  embree-devel
%endif
%if %{with materialx}
BuildRequires:  materialx-devel
%endif
BuildRequires:  opensubdiv-devel >= 3.4.4
%if %{with openshading}
# Use oslc compiler
BuildRequires:  openshadinglanguage-common-headers >= 1.12.6.2
BuildRequires:  pkgconfig(oslcomp)
%endif
%if %{with oidn}
BuildRequires:  cmake(OpenImageDenoise)
%endif
%if %{with opgl}
BuildRequires:  openpgl-devel
%endif
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(ftgl)
BuildRequires:  pkgconfig(glut)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  openxr-libs
BuildRequires:  pkgconfig(openxr)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xrender)
BuildRequires:  pkgconfig(ode)
BuildRequires:  pkgconfig(sdl2)
%if %{with usd}
BuildRequires:  usd-devel
%endif
BuildRequires:  pkgconfig(xproto)

# Picture/Video stuff
BuildRequires:  cmake(Alembic)
BuildRequires:  ffmpeg-free-devel >= 5.1.2
BuildRequires:  lame-devel
BuildRequires:  libspnav-devel
%if %{with nanovdb}
BuildRequires:  openvdb-nanovdb-devel
%endif
%if %{with openvdb}
BuildRequires:  openvdb-devel
%endif
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(vpx)
# OpenColorIO 2 and up required
BuildRequires:  cmake(OpenColorIO) > 1
BuildRequires:  cmake(Imath)
BuildRequires:  cmake(OpenEXR)
BuildRequires:  cmake(OpenImageIO) >= 2.5.0.0
BuildRequires:  pkgconfig(libopenjp2)
BuildRequires:  pkgconfig(tbb) = 2020.3
BuildRequires:  potrace-devel

# Audio stuff
BuildRequires:  jack-audio-connection-kit-devel
BuildRequires:  pkgconfig(ao)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(freealut)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(opus)
BuildRequires:	pkgconfig(libpipewire-0.3)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(vorbis)

# Typography stuff
BuildRequires:  fontpackages-devel
BuildRequires:  pkgconfig(fribidi)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(harfbuzz)
BuildRequires:  pkgconfig(tinyxml)
# Appstream stuff
BuildRequires:  libappstream-glib

# HIP stuff
# https://developer.blender.org/docs/handbook/building_blender/cycles_gpu_binaries/#linux
%if %{with hip}
%if %{with hiprt}
BuildRequires:  hiprt-devel
%endif
BuildRequires:	hipcc
BuildRequires:  rocm-core
BuildRequires:  rocm-device-libs
BuildRequires:  rocm-hip-devel
BuildRequires:  rocm-runtime-devel
%endif

# OneAPU stuff
%if %{with oneapi}
BuildRequires:  pkgconfig(level-zero)
%endif

Requires:       hicolor-icon-theme
Requires:       rsms-inter-fonts
Requires:       shared-mime-info
Provides:       blender(ABI) = %{blender_api}

# Starting from 2.90, Blender support only 64-bits architectures
ExcludeArch:	%{ix86} %{arm}

%description
Blender is the essential software solution you need for 3D, from modeling,
animation, rendering and post-production to interactive creation and playback.

%package rpm-macros
Summary:        RPM macros for third-party blender addons
BuildArch:      noarch

%description rpm-macros
Provides RPM macros for creating third-party addon packages for Blender.

%prep
%autosetup -p1

# System integration fixes
rm -f build_files/cmake/Modules/FindOpenJPEG.cmake
%py3_shebang_fix .
sed -i "s/date_time/date_time python%{python3_version_nodots}/" \
    build_files/cmake/platform/platform_unix.cmake
# Fix proper detection of numpy path
# https://projects.blender.org/blender/blender/issues/137635    
sed -i "s|core/include|_core/include|" CMakeLists.txt

%build
%if %{with hip}
export HIP_PATH=`hipconfig -p`
export HIP_CLANG_PATH=`hipconfig -l`
# On F-41, hipcc wants llvm-objcopy
%if 0%{?fedora} <= 41
export PATH=${PATH}:${HIP_CLANG_PATH}
%endif
%endif

%cmake \
%if %{with ninja}
    -G Ninja \
%endif
    -DBUILD_SHARED_LIBS=OFF \
    -DCMAKE_BUILD_TYPE=Release \
    -DCMAKE_SKIP_RPATH=ON \
    -DPYTHON_VERSION=%{python3_version} \
    -DWITH_COMPILER_CCACHE=ON \
    -DWITH_CYCLES=%{cyclesflag} \
%ifnarch x86_64
    -DWITH_CYCLES_EMBREE=OFF \
%endif
    -DWITH_INSTALL_PORTABLE=OFF \
    -DWITH_PYTHON_INSTALL=OFF \
    %{?with_manpage:-DWITH_DOC_MANPAGE=ON } \
    %{?with_materialx:-DMATERIALX_STDLIB_DIR=%{_datadir}/materialx} \
    %{!?with_materialx:-DWITH_MATERIALX=OFF} \
    %{?with_openshading:-DOSL_COMPILER=%{_bindir}/oslc} \
    %{?with_usd:-DUSD_LIBRARY=%{_libdir}/libusd_ms.so} \
    %{!?with_usd:-DWITH_USD=OFF} \
    -D_ffmpeg_INCLUDE_DIR=$(pkg-config --variable=includedir libavformat) \
    -DEMBREE_INCLUDE_DIR=%{_includedir} \
    -DXR_OPENXR_SDK_LOADER_LIBRARY=%{_libdir}/libopenxr_loader.so.1 \
%if %{with hip}
    -DHIP_HIPCC_EXECUTABLE=%{_bindir}/hipcc \
    -DWITH_CYCLES_HIP_BINARIES=ON \
    %{?with_hiprt:-DWITH_CYCLES_DEVICE_HIPRT=ON} \
%endif
    %{?with_oneapi:-DWITH_CYCLES_DEVICE_ONEAPI=ON} \
    -DWITH_OPENCOLLADA=OFF \
    -DWITH_LIBS_PRECOMPILED=OFF \
    -W no-dev

%cmake_build

%install
%cmake_install

%if %{with manpage}
# See source/creator/CMakeLists.txt.
# This doesn’t work in %%cmake_install because the assumption is that the
# blender executable and the libraries are installed directly to the correct
# system-wide paths. It is easier to re-run the man-page generator manually
# than to patch out this assumption.
LD_LIBRARY_PATH='%{buildroot}%{_libdir}' %{python3} doc/manpage/blender.1.py \
    --blender '%{buildroot}%{_bindir}/blender' \
    --output '%{buildroot}%{_mandir}/man1/blender.1'
%endif

# Additional installs
install -Dm755 release/bin/%{name}-softwaregl %{buildroot}%{_bindir}/%{name}-softwaregl
mkdir -p %{buildroot}%{macrosdir}
install -pm 644 %{SOURCE1} %{buildroot}%{macrosdir}/macros.%{name}
sed -i 's/@VERSION@/%{blender_api}/g' %{buildroot}%{macrosdir}/macros.%{name}

# Metainfo
install -p -m 644 -D release/freedesktop/org.%{name}.Blender.metainfo.xml \
          %{buildroot}%{_metainfodir}/org.%{name}.Blender.metainfo.xml

# Localization and cleanup
%find_lang %{name}
find %{buildroot}%{_datadir}/%{name}/%{blender_api}/scripts -name "*.py" -exec chmod 755 {} \;
rm -rf %{buildroot}%{_docdir}/%{name}/*

%check
desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}.desktop
appstream-util validate-relax --nonet %{buildroot}%{_metainfodir}/org.%{name}.Blender.metainfo.xml

%files -f %{name}.lang
%license COPYING doc/license/*-license.txt release/text/copyright.txt
%doc release/text/readme.html
%{_bindir}/%{name}{,-softwaregl,-thumbnailer}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/%{name}/%{blender_api}/
%{_datadir}/icons/hicolor/*/apps/%{name}*.*
%{_metainfodir}/org.%{name}.Blender.metainfo.xml
%{?with_manpage:%{_mandir}/man1/%{name}.*}

%files rpm-macros
%{macrosdir}/macros.%{name}

%changelog
## START: Generated by rpmautospec
* Fri May 02 2025 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.4.3-1
- Update to 4.4.3

* Wed Apr 23 2025 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.4.1-2
- Switch to pcre2 dependencies over the deprecitaed pcre

* Thu Apr 17 2025 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.4.1-1
- Update to 4.4.1 (rhbz#2359714)

* Tue Apr 15 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 1:4.4.0-6
- Rebuilt for openshadinglanguage 1.14.5.0

* Mon Apr 07 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 1:4.4.0-5
- Rebuilt for openvdb 12

* Thu Apr 03 2025 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.4.0-4
- Enable pipewire support

* Wed Apr 02 2025 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.4.0-3
- Reenable s390x support

* Tue Apr 01 2025 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.4.0-2
- Update to 4.4.0

* Tue Apr 01 2025 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.4.0-1
- Update to 4.4.0

* Sat Feb 15 2025 Robert-André Mauchin <zebob.m@gmail.com> - 1:4.3.2-5
- Fix FTBFS by depending on pipewire-jack-audio-connection-kit-devel

* Sun Feb 02 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 1:4.3.2-4
- Rebuilt for OpenUSD 25.02
- Fix RHBZ#2339934, fix RHBZ#2342539, fix RHBZ#2327275

* Thu Jan 16 2025 Fedora Release Engineering <releng@fedoraproject.org> - 1:4.3.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Wed Jan 15 2025 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.3.2-2
- Enable ninja build

* Tue Jan 14 2025 Michael J Gruber <mjg@fedoraproject.org> - 1:4.3.2-1
- Update to version 4.3.2 (rhbz#2327275)

* Thu Dec 19 2024 Tom Rix <Tom.Rix@amd.com> - 1:4.2.3-4
- Update for ROCm 6.3

* Fri Nov 22 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1:4.2.3-3
- Rebuild for usd 24.11

* Tue Nov 12 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.2.3-2
- Fix crash on creating fluid domain with python 3.12+ (rhbz#2324831)

* Sun Oct 27 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.2.3-1
- Update version to 4.2.3 (rhbz#2318763)

* Thu Oct 24 2024 Orion Poplawski <orion@nwra.com> - 1:4.2.2-11
- Name the RPM macros file properly

* Tue Oct 22 2024 Miro Hrončok <miro@hroncok.cz> - 1:4.2.2-10
- Build with Python 3.13
- Fixes: rhbz#2291492

* Thu Oct 10 2024 Nicolas Chauvet <kwizart@gmail.com> - 1:4.2.2-9
- Fix distribution of compressed macro

* Thu Oct 10 2024 Nicolas Chauvet <kwizart@gmail.com> - 1:4.2.2-8
- Remove mention of the compressed macros

* Thu Oct 10 2024 Nicolas Chauvet <kwizart@gmail.com> - 1:4.2.2-7
- Add blender-macros in SCM

* Thu Oct 10 2024 Richard Shaw <hobbes1069@gmail.com> - 1:4.2.2-6
- Rebuild for OpenColorIO 2.4.0.

* Fri Oct 04 2024 Mamoru TASAKA <mtasaka@fedoraproject.org> - 1:4.2.2-5
- Some workaround for llvm18 compat package series

* Wed Oct 02 2024 Neal Gompa <ngompa@fedoraproject.org> - 1:4.2.2-4
- Rebuild for ffmpeg 7

* Sat Sep 28 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.2.2-3
- Fix addons installation path to adhere blender guideline

* Fri Sep 27 2024 Dominik 'Rathann' Mierzejewski <dominik@greysector.net> - 1:4.2.2-2
- Add upstream PRs to fix build with FFmpeg 7

* Tue Sep 24 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.2.2-1
- Update to 4.2.2 (rhbz#2314401)

* Tue Sep 24 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.2.1-5
- Rebuild with hip support for oidn

* Mon Sep 23 2024 Fabio Valentini <decathorpe@gmail.com> - 1:4.2.1-4
- Rebuild for ffmpeg 7

* Wed Sep 04 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1:4.2.1-3
- Rebuilt for usd-24.08

* Sun Aug 25 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.2.1-2
- Rebuild with python 3.12 for Fedora 41 and Rawhide

* Sun Aug 25 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.2.1-1
- Update to 4.2.1 (rhbz#2305995)

* Sat Jul 27 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.2.0-5
- Restore s390x architecture support ... This update also update path to
  install new Blender extension system wide.

* Thu Jul 25 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.2.0-4
- Restore s390x architecture support ... This update also update path to
  install new Blender extension system wide.

* Thu Jul 25 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.2.0-3
- Restore s390x architecture support ... This update also update path to
  install new Blender extension system wide.

* Wed Jul 24 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.2.0-2
- Temporarily disable s390x support due to endian bug

* Tue Jul 23 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.2.0-1
- Update to 4.2.0 (rhbz#2298215) ... - This update drop conditional Wayland
  support now enabled by default - Dropped explicit add-ons packages as
  upstream moved to extensions - Moved macros file to compressed format
  (tar.xz)

* Wed Jul 17 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1:4.1.1-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Fri Jun 28 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.1.1-9
- Rebuild for OpenImageIO 2.5.12.0 (rhbz#2294166)

* Wed Jun 26 2024 Python Maint <python-maint@redhat.com> - 1:4.1.1-8
- Rebuilt for Python 3.13

* Mon Jun 10 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.1.1-7
- Add recommends rocm-hip-devel (rhbz#2276669)

* Mon Jun 10 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.1.1-6
- Rebuild for openvdb with required tbb2020.3

* Tue May 28 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.1.1-5
- Rebuild for oidn 2.3.0 beta and ispc 1.2.4

* Thu Apr 25 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1:4.1.1-4
- Rebuilt for openexr 3.2.4 and OpenColorIO 2.3.2

* Sun Apr 21 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1:4.1.1-3
- Fix blank blender.1 man page

* Sun Apr 21 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1:4.1.1-2
- More carefully account for Python dependencies
- Add missing runtime/install-time dependencies
- Add weak dependencies used by included add-ons

* Sat Apr 20 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.1.1-1
- Update to 4.1.1 (rhbz#2271664)

* Tue Apr 16 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.1.0-2
- Temporarily disable openshadinglanguage and openvdb due compatibility
  issues

* Fri Mar 29 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.1.0-1
- Update to 4.1.0 (rhbz#2271664)

* Sun Mar 17 2024 Yaakov Selkowitz <yselkowi@redhat.com> - 1:4.0.2-6
- Fix flatpak build

* Sat Feb 17 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.0.2-5
- Reintroduce pylongobject fix (rhbz#2259558, rhbz#2261013)
- Update HIP command on build
- Temporarily disable manpage due to upstream bug

* Tue Jan 30 2024 Richard Shaw <hobbes1069@gmail.com> - 1:4.0.2-4
- Rebuild for OpenImageIO 2.5.x.

* Tue Jan 23 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1:4.0.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Fri Jan 19 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1:4.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sun Dec 10 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.0.2-1
- Update to 4.0.2 (fedora#2253092)

* Sat Nov 25 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:4.0.1-1
- Update to 4.0.1 (fedora#2249635) - Disable manpage broken upstream -
  Upstream patch for aarch64 and ppc69le architectures

* Tue Nov 14 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.6.5-4
- Use new bcond styleb(rpm 4.17+) and fix blender addons macros

* Sun Nov 05 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1:3.6.5-3
- Rebuild for usd-23.11

* Fri Oct 27 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1:3.6.5-2
- Rebuild for openvdb-10.2.0 (close RHBZ#2246605)

* Sat Oct 21 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.6.5-1
- Update to 3.6.5 (rhbz#2245226)

* Wed Sep 27 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.6.4-1
- Update to 3.6.4

* Mon Sep 25 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.6.3-4
- Update to 3.6.3 (rhbz#2240306)

* Mon Sep 25 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.6.3-3
- Update to 3.6.3 (rhbz#2240306)

* Mon Sep 25 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.6.3-2
- Update to 3.6.3 (rhbz#2240306)

* Mon Sep 25 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.6.3-1
- Update to 3.6.3 (#2240306)

* Fri Sep 15 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.6.2-1
- Update to 3.6.2 (rhbz#2232765) Resolve rhbz#2237533

* Fri Sep 01 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1:3.6.1-3
- Rebuilt for usd 23.08

* Fri Aug 04 2023 Mamoru TASAKA <mtasaka@fedoraproject.org> - 1:3.6.1-2
- Apply trial patches for python3.12 compatibility

* Thu Jul 27 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.6.1-1
- Update to 3.6.1 (rhbz#2223840)

* Sun Jul 23 2023 Python Maint <python-maint@redhat.com> - 1:3.6.0-4
- Rebuilt for Python 3.12

* Wed Jul 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1:3.6.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Tue Jul 18 2023 Python Maint <python-maint@redhat.com> - 1:3.6.0-2
- Rebuilt for Python 3.12

* Thu Jun 29 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.6.0-1
- Update to 3.6.0 (rhbz#2218007)

* Wed Jun 28 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1:3.5.1-8
- Drop openCOLLADA support (close RHBZ#2218037)

* Tue Jun 20 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.5.1-7
- Enable clang for rocm-hip build dependency

* Tue Jun 20 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.5.1-6
- Restore international language support

* Sun Jun 18 2023 Tom Rix <trix@redhat.com> - 1:3.5.1-5
- Enable building cycle hip options --with rocm

* Tue May 30 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.5.1-4
- Rebuild for oidn 2.0.0

* Thu May 11 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.5.1-3
- Rebuild for dracon 1.5.6

* Wed May 03 2023 Orion Poplawski <orion@nwra.com> - 1:3.5.1-2
- Fix macros.blender-rpm source reference (bz#2189871)

* Fri Apr 28 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.5.1-1
- Update to 3.5.1 (#2189994)

* Tue Apr 25 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.5.0-7
- Rename macros file extension to avoid confusion with upstream

* Tue Apr 25 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.5.0-6
- Rename macros file extension to avoid confusion with upstream

* Mon Apr 24 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1:3.5.0-5
- Rebuild for USD 23.05

* Mon Apr 24 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1:3.5.0-4
- Remove || from %%%%ifarch

* Sun Apr 23 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.5.0-3
- Include missing addon unbundled by upsteam

* Mon Apr 17 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1:3.5.0-2
- Adjust cmake invocation so USD v23 can be found

* Tue Apr 04 2023 aekoroglu <aekoroglu@linux.intel.com> - 1:3.5.0-1
- update to 3.5.0 and ignore the precompiled libraries

* Sun Mar 12 2023 Neal Gompa <ngompa@fedoraproject.org> - 1:3.4.1-16
- Add patch to fix build with ffmpeg >= 6.0

* Sun Mar 12 2023 Neal Gompa <ngompa@fedoraproject.org> - 1:3.4.1-15
- Rebuild for ffmpeg 6.0

* Thu Mar 09 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1:3.4.1-14
- Fix building with boost >= 1.81 (fix RHBZ#2172445)

* Wed Mar 01 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.4.1-13
- Switch back to embree 3 series

* Mon Feb 20 2023 Jonathan Wakely <jwakely@redhat.com> - 1:3.4.1-12
- Rebuilt for Boost 1.81

* Sun Feb 12 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.4.1-11
- Further port to embree4

* Sun Feb 12 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.4.1-10
- Port to embree4

* Sat Feb 11 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.4.1-9
- Rebuild for embree-4.0.0

* Tue Jan 31 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.4.1-8
- Add missing patch fixing include

* Mon Jan 30 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.4.1-7
- Patch for missing include library due to GCC 13

* Wed Jan 18 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1:3.4.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Sat Jan 14 2023 Orion Poplawski <orion@nwra.com> - 1:3.4.1-5
- Rebuild for libharu 2.4.3

* Sat Jan 14 2023 Orion Poplawski <orion@nwra.com> - 1:3.4.1-4
- Drop eigen3 workaround

* Fri Jan 13 2023 Richard Shaw <hobbes1069@gmail.com> - 1:3.4.1-3
- Rebuild for OpenColorIO.

* Mon Jan 02 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.4.1-2
- Rebuild for openvdb 10.0.1

* Sat Dec 24 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.4.1-1
- Update to 3.4.1 (#2155366)

* Sat Dec 10 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.4.0-2
- Enable openpgl support

* Fri Dec 09 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.4.0-1
- Update to 3.4.0 (#2152009)

* Thu Nov 17 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.3.1-3
- Enable dbus support

* Sat Oct 08 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.3.1-2
- Update to 3.3.1

* Fri Oct 07 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.3.1-1
- Update to 3.3.1 (#2132385)

* Wed Sep 14 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.3.0-4
- Synchronise all branches

* Mon Sep 12 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.3.0-2
- Drop end of life release support

* Mon Sep 12 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.3.0-1
- Update to 3.3.0 (#2125188) * Enable inital wayland support with libdecor

* Mon Aug 29 2022 Neal Gompa <ngompa@fedoraproject.org> - 1:3.2.2-2
- Rebuild for ffmpeg 5.1 (#2121070)

* Thu Aug 04 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1:3.2.2-1
- Update to 3.2.2 (close RHBZ#2115219)

* Thu Aug 04 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1:3.2.1-4
- Update URLs to HTTPS

* Wed Jul 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1:3.2.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Jul 11 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.2.1-2
- Synchronize release with F35 version

* Sat Jul 09 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.2.1-1
- local build

* Thu Jul 07 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1:3.2.0-7
- Replace a downstream patch with an upstream one
- Backport upstream commit 378f65f7d9843ea789a66623019163f935af141e as
  0004-Fix-Py-driver-byte-code-access-with-Python-3.11.patch, replacing
  downstream patch 0001-Support-Python-3.11b3.patch

* Wed Jul 06 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1:3.2.0-6
- Remove trailing whitespace in the spec file

* Wed Jul 06 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1:3.2.0-5
- Backport Python 3.11 support (close RHBZ#2098675)
- Backport the fix for upstream bug T99277 “Fails to compile on Python
  3.11b3 due to opaque PyFrameObject”, along with a related commit
  improving support for Python releases newer than 3.7.
- Add an additional patch required for Python 3.11b3 but not for later
  Python 3.11 pre-releases. This is downstream-only for now, but the
  concept was suggested upstream as a potential general improvement.

* Tue Jun 28 2022 Python Maint <python-maint@redhat.com> - 1:3.2.0-4
- Rebuilt for Python 3.11

* Fri Jun 10 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.2.0-3
- Enable ffpmeg support

* Thu Jun 09 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.2.0-2
- Revert deleted pythonlibs-fix

* Thu Jun 09 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.2.0-1
- Update to 3.2.0 (#2094907)

* Wed Jun 01 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1:3.1.2-6
- Rebuild for usd-22.05a

* Fri May 20 2022 Sandro Mani <manisandro@gmail.com> - 1:3.1.2-5
- Rebuild for gdal-3.5.0 and/or openjpeg-2.5.0

* Wed May 04 2022 Thomas Rodgers <trodgers@redhat.com> - 1:3.1.2-4
- Rebuilt for Boost 1.78

* Sun Apr 10 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1:3.1.2-3
- BR usd-devel instead of cmake(pxr)

* Fri Apr 01 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.1.2-2
- New upstream release 3.1.2

* Fri Apr 01 2022 Fedora Release Monitoring <release-monitoring@fedoraproject.org> - 1:3.1.2-1
- Update to 3.1.2 (#2070344)

* Fri Apr 01 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.1.1-2
- Add missing source

* Fri Apr 01 2022 Fedora Release Monitoring <release-monitoring@fedoraproject.org> - 1:3.1.1-1
- Update to 3.1.1 (#2070344)

* Sun Mar 13 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.1.0-7
- Rebuild to sync with Fedora 35 version

* Sun Mar 13 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.1.0-6
- Rebuild

* Sat Mar 12 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.1.0-5
- Empty commit

* Sat Mar 12 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.1.0-4
- Bump release to sync with f35 version

* Sat Mar 12 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.1.0-3
- oidn support only for x86_64 arch

* Sat Mar 12 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.1.0-2
- Reenable USD support

* Thu Mar 10 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.1.0-1
- Update to blender 3.1.0 Dropped some no longer needed patches

* Mon Feb 28 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.0.1-2
- Bump release

* Tue Feb 22 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.0.1-1
- Update to blender 3.0.1 (#2046570)

* Sun Feb 20 2022 Mamoru TASAKA <mtasaka@fedoraproject.org> - 1:3.0.0-4
- Kill package_note for now because of unknown linkage error

* Wed Jan 19 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1:3.0.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Fri Dec 10 2021 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.0.0-2
- Update Blender to 3.0.0 and remove unused patch

* Thu Dec 09 2021 Luya Tshimbalanga <luya@fedoraproject.org> - 1:3.0.0-1
- local build

* Sat Nov 27 2021 Luya Tshimbalanga <luya@fedoraproject.org> - 1:2.93.6-1
- Update to 2.93.6 with enabled NanoVDB support

* Sat Nov 27 2021 Mamoru TASAKA <mtasaka@fedoraproject.org> - 1:2.93.5-2
- Fix s390x LTO issue on makesrna: force alignment on DNAstr definition in
  makesdna.c (upstream T93425) (bug 1874398)

* Thu Oct 07 2021 Luya Tshimbalanga <luya@fedoraproject.org> - 1:2.93.5-1
- Update to 2.93.5 (#2011379)

* Wed Oct 06 2021 Richard Shaw <hobbes1069@gmail.com> - 1:2.93.4-5
- Add patch for OIIO 2.3+.

* Tue Oct 05 2021 Richard Shaw <hobbes1069@gmail.com> - 1:2.93.4-4
- Rebuild for OpenImageIO 2.3.8.0.

* Wed Sep 29 2021 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1:2.93.4-3
- Rebuild again for alembic 1.8.3

* Sun Sep 12 2021 Luya Tshimbalanga <luya@fedoraproject.org> - 1:2.93.4-2
- Rebuild for alembic 1.8.3

* Fri Sep 03 2021 Luya Tshimbalanga <luya@fedoraproject.org> - 1:2.93.4-1
- Update to 2.93.4 (#2000369) Disable osl due to segmentation fault Remove
  unused patches and macros Resolves rhbz##2000369

* Wed Sep 01 2021 Richard Shaw <hobbes1069@gmail.com> - 1:2.93.3-9
- Rebuild for OpenColorIO 2.1.

* Thu Aug 26 2021 Miro Hrončok <miro@hroncok.cz> - 1:2.93.3-8
- Fix a typo in shared-mime-info, fixes rhbz#1997840

* Tue Aug 24 2021 Richard Shaw <hobbes1069@gmail.com> - 1:2.93.3-7
- Spec file tweaks

* Tue Aug 24 2021 Richard Shaw <hobbes1069@gmail.com> - 1:2.93.3-6
- Forgot git commit -a...

* Tue Aug 24 2021 Richard Shaw <hobbes1069@gmail.com> - 1:2.93.3-5
- Multiple build problem fixes:

* Tue Aug 24 2021 Richard Shaw <hobbes1069@gmail.com> - 1:2.93.3-4
- Try workaround for Eigen3 power10 vs Fedora power8 issue.

* Tue Aug 24 2021 Richard Shaw <hobbes1069@gmail.com> - 1:2.93.3-3
- Rebuild for OpenColorIO 2.

* Sun Aug 22 2021 Luya Tshimbalanga <luya@fedoraproject.org> - 1:2.93.3-2
- Various fixes Fix USD support Enable OSL support for x64 architecture

* Thu Aug 19 2021 Nicolas Chauvet <kwizart@gmail.com> - 1:2.93.3-1
- Update to 2.93.3

* Tue Aug 17 2021 Richard Shaw <hobbes1069@gmail.com> - 1:2.93.1-2
- Add minimal patch for OpenEXR/Imath 3 compatibility.
## END: Generated by rpmautospec
